IndexCommand class

Snapshot of an index mutation.

Annotations
  • @immutable

Constructors

IndexCommand.add(IndexDefinition definition)
factory
IndexCommand.drop(String name)
factory
IndexCommand.fromJson(Map<String, Object?> json)
factory

Properties

definition → IndexDefinition?
Optional index definition carried by the command.
final
hashCode → int
The hash code for this object.
no setterinherited
kind → IndexCommandKind
Index command kind describing add/drop.
final
name → String
Index name targeted by the command.
final
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toJson() → Map<String, Object?>
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited