SeederRegistry class

Registry and runner for database seeders

Constructors

SeederRegistry()

Properties

count → int
Get count of registered seeders
no setter
hashCode → int
The hash code for this object.
no setterinherited
runtimeType → Type
A representation of the runtime type of the object.
no setterinherited

Methods

clear() → void
Clear all registered seeders
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
register(Seeder seeder) → void
Register a seeder
registerAll(List<Seeder> seeders) → void
Register multiple seeders
runAll(DataSource dataSource) → Future<void>
Run all registered seeders in order
toString() → String
A string representation of this object.
inherited

Operators

operator ==(Object other) → bool
The equality operator.
inherited